@@ -11,6 +11,7 @@
 #define USE_WCS_SVR 1
 #define USE_WFS_SVR 1
 #define USE_SOS_SVR 1
+#define USE_OGCAPI_SVR 1
 #define USE_WFS_LYR 1
 #define USE_WMS_LYR 1
 #define USE_CURL 1
@@ -27,7 +28,6 @@
 /* #undef USE_MYSQL */
 /* #undef USE_THREAD */
 #define USE_KML 1
-#define USE_POINT_Z_M 1
 /* #undef USE_ORACLESPATIAL */
 /* #undef USE_EXEMPI */
 /* #undef USE_XMLMAPFILE */
